@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: blaze-markup
 version: 0.7.0.3
-id: blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
-key: blaze_0GHhaMWFHoQLer0aTKr3fi
+id: blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
+key: blaze_C7imNkL0ufD2cjmU64FP9k
 license: BSD3
 maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
 stability: Experimental
@@ -25,12 +25,12 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/blaze-markup-0.7.0.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/blaze-markup-0.7.0.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/blaze-markup-0.7.0.3
-hs-libraries: HSblaze-markup-0.7.0.3-0GHhaMWFHoQLer0aTKr3fi
+hs-libraries: HSblaze-markup-0.7.0.3-C7imNkL0ufD2cjmU64FP9k
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
+    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
 haddock-interfaces: /usr/share/doc/haskell-blaze-markup/html/blaze-markup.haddock
 haddock-html: /usr/share/doc/haskell-blaze-markup/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
